@@ -6,9 +6,8 @@ from .models import Logs
 
 @admin.register(Logs)
 class LogsAdministrator(admin.ModelAdmin):
-    list_display = ["created", 'name', 'levelname', "short_message"]
+    list_display = ["times", 'name', 'levelname', "short_message"]
     search_fields = ["msg"]
-    date_hierarchy = "created"
     list_filter = ["levelname"]
     fieldsets = [
         (
@@ -41,7 +40,7 @@ class LogsAdministrator(admin.ModelAdmin):
         ), (
             "Not Userful", {
                 "fields": [
-                    "created",
+                    "times",
                     "msecs",
                     "relativeCreated",
                     "thread",
