@@ -33,7 +33,7 @@ class Logs(models.Model):
     lineno = models.CharField(max_length=32, verbose_name="Line No", default="")
     funcname = models.CharField(max_length=32, verbose_name="Func Name", default="")
 
-    created = models.DateTimeField(verbose_name="Created Time", default="")
+    created = models.FloatField(verbose_name="Created Time", default=0)
     msecs = models.FloatField(verbose_name="Msecs", default="")
     relativeCreated = models.FloatField(verbose_name="Relative Created", default="")
 
@@ -58,3 +58,14 @@ class Logs(models.Model):
 
     short_message.allow_tags = True
     short_message.short_description = "Short Message"
+
+    def times(self):
+        back: datetime = None
+        try:
+            back = datetime.fromtimestamp(self.created)
+        except Exception:
+            logging.error(traceback.format_exc())
+        return back
+
+    times.allow_tags = True
+    times.short_description = "Create Times"
\ No newline at end of file
